package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.system.domain.SysConfig;
import java.math.RoundingMode;
import java.math.BigDecimal;
import org.springframework.web.bind.annotation.RequestBody;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import org.springframework.web.bind.annotation.PathVariable;
import java.util.List;
import java.util.Collections;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.domain.SnTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.system.service.ISysConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISnTemplateService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/SnClientVersion" })
public class SnClientVersionController extends BaseController
{
    @Autowired
    private ISnTemplateService snTemplateService;
    @Autowired
    private ISysConfigService configService;
    
    @GetMapping({ "/version" })
    public AjaxResult version() {
        final JSONObject json = new JSONObject();
        json.put((Object)"backVersion", (Object)this.configService.selectConfigByKey("sync-client-version"));
        json.put((Object)"uaVersion", (Object)this.configService.selectConfigByKey("client-ua-version"));
        return AjaxResult.success("获取成功", (Object)json);
    }
    
    @GetMapping({ "/list" })
    public TableDataInfo list(final SnTemplate snTemplate) {
        this.startPage();
        if (snTemplate.getCategory() != 0 && snTemplate.getCategory() != 1) {
            final TableDataInfo rspData = new TableDataInfo();
            rspData.setCode(200);
            rspData.setRows((List)Collections.emptyList());
            rspData.setMsg("查询成功");
            rspData.setTotal(0L);
            return rspData;
        }
        final List<SnTemplate> list = this.snTemplateService.selectSnTemplateList(snTemplate);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:clientVersion:query" })
    @GetMapping({ "/{templateId}" })
    public AjaxResult getInfo(@PathVariable("templateId") final Long templateId) {
        return this.success((Object)this.snTemplateService.selectSnTemplateByTemplateId(templateId));
    }
    
    @RequiresPermissions({ "system:clientVersion:add" })
    @Log(title = "客户端版本", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody final SnTemplate snTemplate) {
        if (snTemplate.getCategory() == null || (snTemplate.getCategory() != 0 && snTemplate.getCategory() != 1)) {
            return this.error("分类参数有误");
        }
        snTemplate.setStatus(Integer.valueOf(1));
        final int num = this.snTemplateService.insertSnTemplate(snTemplate);
        final SysConfig config = this.configService.selectConfigByKeyObj("sync-client-version");
        if (config == null) {
            return AjaxResult.error("更新客户端版本失败");
        }
        final BigDecimal version = new BigDecimal(config.getConfigValue()).add(new BigDecimal("0.01")).setScale(2, RoundingMode.HALF_EVEN);
        config.setConfigValue(version.toString());
        this.configService.updateConfig(config);
        return this.toAjax(num);
    }
    
    @RequiresPermissions({ "system:clientVersion:edit" })
    @Log(title = "客户端版本", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody final SnTemplate snTemplate) {
        return this.toAjax(this.snTemplateService.updateSnTemplate(snTemplate));
    }
    
    @RequiresPermissions({ "system:clientVersion:remove" })
    @Log(title = "客户端版本", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{templateIds}" })
    public AjaxResult remove(@PathVariable final Long[] templateIds) {
        return this.snTemplateService.deleteSnTemplateByTemplateIds(templateIds);
    }
}
